.. _source:


.. raw:: html

     <br><br>

.. title:: Source


**GENOCIDE**

.. raw:: html

     <br>

.. autosummary::
    :toctree: 
    :template: base.rst

    genocide.handler	event handler
    genocide.loggers 	logging
    genocide.modules	plugins
    genocide.objects	objects
    genocide.repeats	repeaters
    genocide.threads	threading


.. raw:: html

     <br>


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    genocide.modules.fnd	locate objects
    genocide.modules.irc	internet relay chat
    genocide.modules.log	log text
    genocide.modules.mdl	genocide model
    genocide.modules.req	request
    genocide.modules.rss	rich site syndicate
    genocide.modules.tdo	things todo
